/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.scripting.executor.internal.messaging;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.messaging.BaseMessageListener;
import com.liferay.portal.kernel.messaging.Message;
import com.liferay.portal.kernel.scripting.Scripting;
import com.liferay.portal.kernel.util.AggregateClassLoader;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.scripting.executor.internal.ScriptingExecutorMessagingConstants;

import java.io.InputStream;

import java.net.URL;

import java.util.HashMap;
import java.util.List;

/**
 * @author Michael C. Han
 */
public class ScriptingExecutorMessageListener extends BaseMessageListener {

	public ScriptingExecutorMessageListener(Scripting scripting) {
		_scripting = scripting;
	}

	@Override
	protected void doReceive(Message message) throws Exception {
		Thread currentThread = Thread.currentThread();

		ClassLoader contextClassLoader = currentThread.getContextClassLoader();

		String scriptingLanguage = message.getString(
			ScriptingExecutorMessagingConstants.MESSAGE_KEY_SCRIPTING_LANGUAGE);

		List<URL> urls = (List<URL>)message.get(
			ScriptingExecutorMessagingConstants.MESSAGE_KEY_URLS);

		for (URL url : urls) {
			try (InputStream inputStream = url.openStream()) {
				ClassLoader bundleClassLoader = (ClassLoader)message.get(
					ScriptingExecutorMessagingConstants.
						MESSAGE_KEY_BUNDLE_CLASS_LOADER);

				if (bundleClassLoader != null) {
					ClassLoader aggregateClassLoader =
						AggregateClassLoader.getAggregateClassLoader(
							contextClassLoader, bundleClassLoader);

					currentThread.setContextClassLoader(aggregateClassLoader);
				}

				_scripting.exec(
					null, new HashMap<String, Object>(), scriptingLanguage,
					StringUtil.read(inputStream));
			}
			catch (Exception e) {
				if (_log.isWarnEnabled()) {
					_log.warn("Unable to execute script " + url.getFile(), e);
				}
			}
			finally {
				currentThread.setContextClassLoader(contextClassLoader);
			}
		}
	}

	private static final Log _log = LogFactoryUtil.getLog(
		ScriptingExecutorMessageListener.class);

	private final Scripting _scripting;

}